@@ -21,11 +21,9 @@
 #' plans_05 <- fl25_enum$plans[, fl25_enum$pop_dev <= 0.05]
 #' comp <- redist.competitiveness(plans_05, fl25$mccain, fl25$obama)
 #'
-redist.competitiveness <- function(plans, rvote, dvote, alpha = 1, beta = 1){
-  nd <- length(unique(plans[, 1]))
-  rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
-  dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
-  dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
-  talisman(dvs = dvs, nd = nd, alpha = alpha, beta = beta)
+redist.competitiveness <- function(plans, rvote, dvote, alpha = 1, beta = 1) {
+    nd <- length(unique(plans[, 1]))
+    redistmetrics::compet_talisman(plans = plans, shp = data.frame(),
+        rvote = rvote, dvote = dvote,
+        alpha = alpha, beta = beta)[seq(1, nd*ncol(plans), by = nd)]
 }
